==> qore-0.9.4.tar.bz2: qore-0.9.4/docs/modules/SalesforceRestDataProvider/html/group__soql__soql__cop__funcs.js <==
var group__soql__soql__cop__funcs =
[
    [ "soql_cop_avg", "group__soql__soql__cop__funcs.html#gaff7a4f00af79170a3328dcc82fd3ac6b", null ],
    [ "soql_cop_calendar_month", "group__soql__soql__cop__funcs.html#ga09857f0fd4fc1b6b346b9d2291cf165f", null ],
    [ "soql_cop_calendar_quarter", "group__soql__soql__cop__funcs.html#ga3949977411e58b49172abbc73645082d", null ],
    [ "soql_cop_calendar_year", "group__soql__soql__cop__funcs.html#gaca4abd70b5770028f00d0aca221f831e", null ],
    [ "soql_cop_convert_currency", "group__soql__soql__cop__funcs.html#ga0d5d03033cc42f7a5d9e602bfe79b003", null ],
    [ "soql_cop_count_distinct", "group__soql__soql__cop__funcs.html#gace6ebba0934d4165439e0ffc701058a0", null ],
    [ "soql_cop_day_in_month", "group__soql__soql__cop__funcs.html#gaf6d3d9f8305f3c5933b16e5b03533ab0", null ],
    [ "soql_cop_day_in_week", "group__soql__soql__cop__funcs.html#ga92f1edfa2de1cbd75e2750e568e52255", null ],
    [ "soql_cop_day_in_year", "group__soql__soql__cop__funcs.html#ga095dc7df8a43b157aced22e015b35a45", null ],
    [ "soql_cop_day_only", "group__soql__soql__cop__funcs.html#ga6e34977f25fe2f1b61245fff6bd3689f", null ],
    [ "soql_cop_fiscal_month", "group__soql__soql__cop__funcs.html#ga1279bdff500f6cbafba7b735b3907e14", null ],
    [ "soql_cop_fiscal_quarter", "group__soql__soql__cop__funcs.html#ga14a03791240629378042d5dc8fd1cdcb", null ],
    [ "soql_cop_fiscal_year", "group__soql__soql__cop__funcs.html#ga63275ddaf5e584a05d1fdc1e9d445e2e", null ],
    [ "soql_cop_format", "group__soql__soql__cop__funcs.html#gacbb35a7f87ddeb6758026f2951068621", null ],
    [ "soql_cop_hour_in_day", "group__soql__soql__cop__funcs.html#ga499b729b94724b3d912da5ab8f13b650", null ],
    [ "soql_cop_max", "group__soql__soql__cop__funcs.html#ga525b6ddaff084253b106b1d1833c9284", null ],
    [ "soql_cop_min", "group__soql__soql__cop__funcs.html#ga1b425e814449b2bb8e46cef9923e00fe", null ],
    [ "soql_cop_sum", "group__soql__soql__cop__funcs.html#ga86015af316e2af146791ccf4d331c25b", null ],
    [ "soql_cop_week_in_month", "group__soql__soql__cop__funcs.html#ga9b86400a429db14ee222415b12a1af9a", null ],
    [ "soql_cop_week_in_year", "group__soql__soql__cop__funcs.html#gae71bb939e5f3e16aceebcd05435e3157", null ],
    [ "soql_make_cop", "group__soql__soql__cop__funcs.html#gaf717936c8174e8dc840141e262f1bf23", null ]
];

==> qore-1.0.8.tar.bz2: qore-1.0.8/docs/modules/SalesforceRestDataProvider/html/group__soql__soql__cop__funcs.js <==
var group__soql__soql__cop__funcs =
[
    [ "soql_cop_avg", "group__soql__soql__cop__funcs.html#gaff7a4f00af79170a3328dcc82fd3ac6b", null ],
    [ "soql_cop_calendar_month", "group__soql__soql__cop__funcs.html#ga09857f0fd4fc1b6b346b9d2291cf165f", null ],
    [ "soql_cop_calendar_quarter", "group__soql__soql__cop__funcs.html#ga3949977411e58b49172abbc73645082d", null ],
    [ "soql_cop_calendar_year", "group__soql__soql__cop__funcs.html#gaca4abd70b5770028f00d0aca221f831e", null ],
    [ "soql_cop_convert_currency", "group__soql__soql__cop__funcs.html#ga0d5d03033cc42f7a5d9e602bfe79b003", null ],
    [ "soql_cop_count", "group__soql__soql__cop__funcs.html#ga953eff16954e5907304668ce1fc086ec", null ],
    [ "soql_cop_count_distinct", "group__soql__soql__cop__funcs.html#gace6ebba0934d4165439e0ffc701058a0", null ],
    [ "soql_cop_day_in_month", "group__soql__soql__cop__funcs.html#gaf6d3d9f8305f3c5933b16e5b03533ab0", null ],
    [ "soql_cop_day_in_week", "group__soql__soql__cop__funcs.html#ga92f1edfa2de1cbd75e2750e568e52255", null ],
    [ "soql_cop_day_in_year", "group__soql__soql__cop__funcs.html#ga095dc7df8a43b157aced22e015b35a45", null ],
    [ "soql_cop_day_only", "group__soql__soql__cop__funcs.html#ga6e34977f25fe2f1b61245fff6bd3689f", null ],
    [ "soql_cop_fiscal_month", "group__soql__soql__cop__funcs.html#ga1279bdff500f6cbafba7b735b3907e14", null ],
    [ "soql_cop_fiscal_quarter", "group__soql__soql__cop__funcs.html#ga14a03791240629378042d5dc8fd1cdcb", null ],
    [ "soql_cop_fiscal_year", "group__soql__soql__cop__funcs.html#ga63275ddaf5e584a05d1fdc1e9d445e2e", null ],
    [ "soql_cop_format", "group__soql__soql__cop__funcs.html#gacbb35a7f87ddeb6758026f2951068621", null ],
    [ "soql_cop_hour_in_day", "group__soql__soql__cop__funcs.html#ga499b729b94724b3d912da5ab8f13b650", null ],
    [ "soql_cop_max", "group__soql__soql__cop__funcs.html#ga525b6ddaff084253b106b1d1833c9284", null ],
    [ "soql_cop_min", "group__soql__soql__cop__funcs.html#ga1b425e814449b2bb8e46cef9923e00fe", null ],
    [ "soql_cop_sum", "group__soql__soql__cop__funcs.html#ga86015af316e2af146791ccf4d331c25b", null ],
    [ "soql_cop_week_in_month", "group__soql__soql__cop__funcs.html#ga9b86400a429db14ee222415b12a1af9a", null ],
    [ "soql_cop_week_in_year", "group__soql__soql__cop__funcs.html#gae71bb939e5f3e16aceebcd05435e3157", null ],
    [ "soql_make_cop", "group__soql__soql__cop__funcs.html#gaf717936c8174e8dc840141e262f1bf23", null ]
];
